@@ -72,7 +72,6 @@ check_overdispersion <- function(x, ...) {
 }
 
 
-
 # default -----------------------
 
 #' @export
@@ -84,7 +83,6 @@ check_overdispersion.default <- function(x, ...) {
 }
 
 
-
 # Methods -----------------------------
 
 #' @export
@@ -101,7 +99,7 @@ plot.check_overdisp <- function(x, ...) {
     }
   }
   if (!is.null(model)) {
-    x <- .diag_overdispersion(model)
+    x <- .model_diagnostic_overdispersion(model)
     class(x) <- c("see_check_overdisp", "data.frame")
     attr(x, "colors") <- list(...)$colors
     attr(x, "line_size") <- list(...)$size_line
@@ -150,7 +148,6 @@ print.check_overdisp <- function(x, digits = 3, ...) {
 }
 
 
-
 # Overdispersion for classical models -----------------------------
 
 #' @export
@@ -287,8 +284,11 @@ check_overdispersion.glmmTMB <- check_overdispersion.merMod
 
 #' @rdname check_overdispersion
 #' @export
-check_overdispersion.performance_simres <- function(x, alternative = c("two.sided", "less", "greater"), ...) {
-  alternative <- match.arg(alternative)
+check_overdispersion.performance_simres <- function(x, alternative = "two.sided", ...) {
+  alternative <- insight::validate_argument(
+    alternative,
+    c("two.sided", "less", "greater")
+  )
 
   # check for special arguments - we may pass "object_name" from other methods
   dots <- list(...)
