@@ -52,7 +52,6 @@ print.r2_generic <- function(x, digits = 3, ...) {
 }
 
 
-
 #' @export
 print.r2_pseudo <- function(x, digits = 3, ...) {
   model_type <- attr(x, "model_type")
@@ -64,7 +63,6 @@ print.r2_pseudo <- function(x, digits = 3, ...) {
 }
 
 
-
 #' @export
 print.r2_mlm <- function(x, digits = 3, ...) {
   model_type <- attr(x, "model_type")
@@ -106,7 +104,6 @@ print.r2_mlm <- function(x, digits = 3, ...) {
 }
 
 
-
 #' @export
 print.r2_bayes <- function(x, digits = 3, ...) {
   insight::print_color("# Bayesian R2 with Compatibility Interval\n\n", "blue")
@@ -138,7 +135,6 @@ print.r2_bayes <- function(x, digits = 3, ...) {
 }
 
 
-
 #' @export
 print.r2_loo <- function(x, digits = 3, ...) {
   insight::print_color("# LOO-adjusted R2 with Compatibility Interval\n\n", "blue")
@@ -170,7 +166,6 @@ print.r2_loo <- function(x, digits = 3, ...) {
 }
 
 
-
 #' @export
 print.r2_nakagawa_by_group <- function(x, digits = 3, ...) {
   insight::print_color("# Explained Variance by Level\n\n", "blue")
@@ -178,3 +173,14 @@ print.r2_nakagawa_by_group <- function(x, digits = 3, ...) {
   cat("\n")
   invisible(x)
 }
+
+
+# we allow exporting HTML format based on "gt" or "tinytable"
+.check_format_backend <- function(...) {
+  dots <- list(...)
+  if (identical(dots$backend, "tt")) {
+    "tt"
+  } else {
+    "html"
+  }
+}
